==============================
Models Signal
==============================

Signal
-------------------

.. autoclass:: exorad.models.signal.Signal
    :members:
    :undoc-members:
    :show-inheritance:

Signal
-------------------

.. autoclass:: exorad.models.signal.Signal
    :members:
    :undoc-members:
    :show-inheritance:

Custom Signal
-------------------

.. autoclass:: exorad.models.signal.CustomSignal
    :members:
    :undoc-members:
    :show-inheritance:

Sed
-------------------

.. autoclass:: exorad.models.signal.Sed
    :members:
    :undoc-members:
    :show-inheritance:

Radiance
-------------------

.. autoclass:: exorad.models.signal.Radiance
    :members:
    :undoc-members:
    :show-inheritance:

CountsPerSeconds
-------------------

.. autoclass:: exorad.models.signal.CountsPerSeconds
    :members:
    :undoc-members:
    :show-inheritance:

